@@ -1054,8 +1054,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 outline['AgeFrequency'] = self.WordType.getFreq(subset='age',speaker=self.Dialog.Speaker)
             if 'G' in form['lexical_scale'] and 'GenderFrequency' not in outline:
                 outline['GenderFrequency'] = self.WordType.getFreq(subset='gender',speaker=self.Dialog.Speaker)
-            if 'D' in form['DialogFrequency'] and 'DialogFrequency' not in outline:
-                outline['DialogNeighDen'] = self.WordType.getFreq(subset='dialog',speaker=self.Dialog.Speaker,dialog=self.Dialog)
+            if 'D' in form['lexical_scale'] and 'DialogFrequency' not in outline:
+                outline['DialogFrequency'] = self.WordType.getFreq(subset='dialog',speaker=self.Dialog.Speaker,dialog=self.Dialog)
 
         if form['gender']:
             if 'SpeakerGender' not in outline:
